# Syndp
Synthetic Data Generation method leveraging Differential Privacy with variety of mechanisms. This package also presents metrics for calculating simmilarity and privacy risks

---
- Author : Won Seok Jang

---
This is a package that anyone can use for synthesizing new data. This pacakage leverages local differential privacy and other techniques.